# LeRobot SO-ARM-100 6 DOF robotic arm manipulation with Genesis simulator and Feetech motors

There are 2 main use cases

1. sim to real, where genesis controls the physical robot
2. real to sim, where the physical robot moves will refresh the robot rendering in genesis

## TOC

- [Acknowledgements](doc/acknowledgements.md)
- [Installation](doc/installation.md)
- [Calibration & Validation](doc/calibration_validation.md)
- [Real 2 Sim](doc/real2sim.md)
- [Policies](doc/policies.md)
- [Tele-operation](doc/teleoperate.md)
- [Examples](doc/examples.md)
- [Gradio apps](doc/gradio_apps.md)
- [LeRobot dataset EDA](notebooks/so100_ball_cup2.ipynb)